
# q-expansion of newform 2160.3.e.d, downloaded from the LMFDB on 11 March 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2160
weight = 3
poly_data = [1, -9, 75, -100, 251, -9, 552, -157, 127, -22, 17, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-82445821, -11521242, 95555925, 898575342, 278077614, 109810233, 78077829, 20002182, 10429977, 464070, 773970, 103995], 14223533], [[-150738759, 2687029262, 1425970267, 4236239837, -3278893818, 3849241095, -1347172155, 730725662, -192320617, 91074959, -17235734, 3992325], 113788264], [[20411, -14916, 123675, 150327, 356524, 151959, 12439, 43732, 1223, 5725, -692, 453], 8104], [[-9893094, 72717786, -602926725, -82696410, -1737361838, -742920489, -47413418, -217019654, -3332617, -29928170, 3736366, -2276619], 28447066], [[153002422, 112143270, -929860725, -1904989776, -2683546898, -1133818905, -173038478, -313022954, -20051353, -38696408, 3705058, -3124347], 28447066], [[-132280207, 2050150500, -1986724959, 6822605925, -133903996, 14500601557, -4088239995, 3331647244, -574434731, 445393367, -78376428, 26184127], 113788264], [[-1565756991, 720776271, -5976309000, -7297388895, -17232033005, -7331923704, -709828427, -2093028845, -73009024, -273027365, 31520113, -21529392], 56894132], [[42557, -623886, 996350, -2470392, -436520, -5602138, 1525832, -1304826, 214132, -174968, 30530, -10470], 14041], [[971707293, -14163509326, 23790556463, -58072471503, -9095546598, -134365483173, 36850259201, -31342227150, 5169350411, -4204791829, 733868086, -251724799], 113788264], [[-909225421, 13123574708, -24181516361, 58253918431, 4652770164, 141303358323, -39637540153, 32800710252, -5562076365, 4406374085, -775667068, 261532761], 113788264], [[2749676847, -41520514382, 52066332393, -149363404557, -13685083990, -326371292915, 90073054875, -75603246718, 12648064621, -10121230575, 1770509206, -601540329], 113788264]]

hecke_ring_character_values = [[271, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1621, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2081, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1297, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [-1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0], [-7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, -1, -1, -1, 0], [0, 0, 1, 0, 0, 0, -3, 0, -1, 0, 0, -1], [-11, -1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 3, 0, 0, -1, 1, 1], [6, -3, 0, 8, 0, 1, 0, 0, 0, 0, 0, 0], [-7, 0, 0, 1, 2, -1, 0, 2, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, -9, 0, -5, -1, 3, -1], [0, 0, -5, 0, 0, 0, -4, 0, 3, 2, 2, 1], [-1, 0, 0, -2, -1, -1, 0, -4, 0, 0, 0, 0], [0, 0, 6, 0, 0, 0, -5, 0, -1, 1, 2, 1], [1, 0, 0, 16, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 0, 0, 9, 0, -9, 1, -1, -1], [0, 0, 2, 0, 0, 0, -14, 0, -6, -2, 1, 2], [-7, 0, 0, 21, -6, 2, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -11, 0, -7, 3, -5, 2], [0, 0, 3, 0, 0, 0, 19, 0, 11, -2, 0, 1], [-25, 3, 0, -5, -4, -4, 0, 2, 0, 0, 0, 0], [20, 3, 0, 32, 0, -5, 0, 0, 0, 0, 0, 0], [24, 1, 0, 8, -2, 1, 0, 4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 23, 0, -5, 3, 5, 1], [0, 0, -15, 0, 0, 0, 18, 0, -9, 0, -2, -3], [15, 3, 0, 38, 3, -3, 0, 2, 0, 0, 0, 0], [58, 1, 0, -8, 5, -1, 0, -4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, -7, 1, 3, 1], [0, 0, 0, 0, 0, 0, 47, 0, 1, 5, -1, -1], [35, 6, 0, 16, 11, -1, 0, -4, 0, 0, 0, 0], [0, 0, 4, 0, 0, 0, 30, 0, -22, -2, -6, -2], [-37, 3, 0, 7, 14, -10, 0, -4, 0, 0, 0, 0], [0, 0, 9, 0, 0, 0, -22, 0, -13, -4, 2, -3], [-15, 0, 0, 49, -6, 12, 0, 1, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, -21, 0, -33, -1, 1, 7], [0, 0, -16, 0, 0, 0, -13, 0, -4, -4, -6, 6], [83, -3, 0, 28, -10, -4, 0, 8, 0, 0, 0, 0], [0, 0, 12, 0, 0, 0, -10, 0, -26, 2, -4, 2], [35, 3, 0, 58, 15, -3, 0, -2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 11, 0, 37, 5, 3, -1], [-1, -3, 0, 65, 12, -1, 0, -5, 0, 0, 0, 0], [11, 6, 0, -44, 5, 5, 0, -4, 0, 0, 0, 0], [0, 0, -4, 0, 0, 0, -14, 0, -8, -6, 2, -8], [0, 0, -19, 0, 0, 0, 21, 0, -40, -1, -7, -3], [0, 0, -10, 0, 0, 0, 35, 0, 7, -5, -11, -9], [0, 0, -8, 0, 0, 0, 3, 0, 44, -12, 6, -4], [31, -15, 0, 48, -15, 15, 0, 12, 0, 0, 0, 0], [116, -2, 0, -30, 6, 6, 0, 12, 0, 0, 0, 0], [0, 0, 2, 0, 0, 0, -64, 0, -4, -10, 12, 0], [53, -3, 0, 34, -9, 21, 0, 10, 0, 0, 0, 0], [0, 0, 8, 0, 0, 0, -4, 0, -40, -4, 10, 0], [13, -14, 0, -38, -25, 5, 0, 8, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 26, 0, 53, 8, -8, 3], [-218, -6, 0, -64, 4, 4, 0, 4, 0, 0, 0, 0], [0, 0, 3, 0, 0, 0, 3, 0, 24, -1, 1, 13], [-87, -9, 0, 65, -6, -9, 0, 5, 0, 0, 0, 0], [19, 1, 0, 61, 2, -10, 0, -10, 0, 0, 0, 0], [0, 0, 7, 0, 0, 0, -28, 0, -44, 0, -10, -2], [69, 10, 0, 38, 7, -17, 0, 4, 0, 0, 0, 0], [0, 0, -8, 0, 0, 0, 98, 0, -44, 6, -10, -2], [0, 0, -4, 0, 0, 0, -28, 0, -28, -10, -5, -12], [14, 12, 0, 30, 6, -12, 0, 6, 0, 0, 0, 0], [-15, 5, 0, 100, 20, -10, 0, -16, 0, 0, 0, 0], [0, 0, 24, 0, 0, 0, 70, 0, -28, 2, -10, 0], [163, 0, 0, -3, 12, 18, 0, -9, 0, 0, 0, 0], [0, 0, 26, 0, 0, 0, -34, 0, -16, 2, -10, -12], [-125, 12, 0, 6, -12, -14, 0, -2, 0, 0, 0, 0], [190, 2, 0, 72, 0, 24, 0, 0, 0, 0, 0, 0], [0, 0, -16, 0, 0, 0, -101, 0, -63, 1, -3, -13], [0, 0, -25, 0, 0, 0, 39, 0, 59, 11, -7, -3], [-22, 15, 0, -10, 0, -1, 0, -2, 0, 0, 0, 0], [0, 0, 13, 0, 0, 0, -69, 0, -38, 1, 7, -9], [0, 0, -16, 0, 0, 0, 139, 0, 0, -20, 12, 2], [-319, 14, 0, 53, -20, 7, 0, 16, 0, 0, 0, 0], [23, -9, 0, -39, -30, 3, 0, -3, 0, 0, 0, 0], [212, 3, 0, -50, 14, -25, 0, 8, 0, 0, 0, 0], [-103, 21, 0, -44, 9, 9, 0, -8, 0, 0, 0, 0], [0, 0, -16, 0, 0, 0, -150, 0, -38, 18, 5, -2], [-123, 12, 0, -26, 30, 14, 0, -18, 0, 0, 0, 0], [0, 0, -12, 0, 0, 0, 109, 0, -79, 7, -26, 7], [-19, 0, 0, -45, 30, -6, 0, -3, 0, 0, 0, 0], [0, 0, 13, 0, 0, 0, 87, 0, 64, -13, -3, 5], [0, 0, -13, 0, 0, 0, 51, 0, 79, -6, 10, -11], [-355, -11, 0, -45, 0, 24, 0, -6, 0, 0, 0, 0], [98, -3, 0, -38, 24, -27, 0, -14, 0, 0, 0, 0], [230, -17, 0, 120, -6, 33, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 0, 0, 14, 0, 98, -6, -2, 8], [0, 0, 42, 0, 0, 0, -27, 0, -60, -18, 20, 12], [0, 0, -32, 0, 0, 0, -38, 0, 124, -2, -5, 0], [0, 0, -5, 0, 0, 0, 158, 0, 82, -14, 10, 0], [0, 0, -10, 0, 0, 0, 49, 0, -15, 7, 11, 23], [0, 0, 19, 0, 0, 0, -15, 0, -60, -17, -7, -1], [0, 0, -17, 0, 0, 0, 151, 0, -89, -2, 22, 3], [-336, -28, 0, 28, -4, 32, 0, -4, 0, 0, 0, 0], [109, 28, 0, 13, -10, -25, 0, 2, 0, 0, 0, 0], [0, 0, -39, 0, 0, 0, 18, 0, 16, -6, 20, 4], [50, 15, 0, -124, -21, 7, 0, 24, 0, 0, 0, 0], [0, 0, -13, 0, 0, 0, 18, 0, -56, -14, -8, -6], [234, -2, 0, -196, -2, -20, 0, 16, 0, 0, 0, 0], [0, 0, -13, 0, 0, 0, 182, 0, -7, 20, -18, -9], [-425, -15, 0, 101, 22, -14, 0, 22, 0, 0, 0, 0], [0, 0, -31, 0, 0, 0, 7, 0, 16, -11, 31, 15], [-347, -15, 0, -95, 12, -1, 0, 15, 0, 0, 0, 0], [0, 0, 35, 0, 0, 0, -129, 0, 97, 12, -22, -5], [489, 28, 0, -46, 1, 19, 0, -32, 0, 0, 0, 0], [0, 0, -54, 0, 0, 0, -54, 0, 0, 0, -21, 0], [119, -3, 0, -210, -21, 21, 0, 6, 0, 0, 0, 0], [0, 0, 13, 0, 0, 0, -199, 0, 123, -3, -33, -21], [228, 0, 0, -172, 30, -8, 0, 12, 0, 0, 0, 0], [1, 10, 0, -32, 53, -19, 0, -4, 0, 0, 0, 0], [0, 0, -64, 0, 0, 0, 54, 0, 8, 6, -38, -28], [0, 0, 18, 0, 0, 0, 33, 0, 83, -5, -9, -20], [224, 10, 0, 120, -6, -18, 0, 36, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 139, 0, -57, -5, -1, -7], [0, 0, 26, 0, 0, 0, 3, 0, -122, -36, -24, -8], [439, 19, 0, 58, 14, -22, 0, -16, 0, 0, 0, 0], [0, 0, -8, 0, 0, 0, -300, 0, 74, -18, 1, -10], [174, -15, 0, -160, 9, -11, 0, -36, 0, 0, 0, 0], [63, -12, 0, -151, -18, 22, 0, -21, 0, 0, 0, 0], [62, -31, 0, 128, -29, 43, 0, 28, 0, 0, 0, 0], [0, 0, -8, 0, 0, 0, 97, 0, -62, -38, -34, -6], [0, 0, 37, 0, 0, 0, -117, 0, -70, 9, 31, 11], [120, 15, 0, -234, -36, 15, 0, 12, 0, 0, 0, 0], [-142, -27, 0, -88, 15, 13, 0, 12, 0, 0, 0, 0], [0, 0, 40, 0, 0, 0, -200, 0, -110, -2, 2, 18], [0, 0, -4, 0, 0, 0, -192, 0, 102, 20, 52, 22], [-316, -33, 0, -104, -30, 15, 0, 16, 0, 0, 0, 0], [0, 0, 57, 0, 0, 0, -223, 0, -86, 11, -27, 23], [0, 0, 14, 0, 0, 0, 52, 0, -90, 28, -8, 2], [0, 0, 4, 0, 0, 0, 211, 0, 175, -3, -7, -20], [-496, 21, 0, -94, 18, 1, 0, -30, 0, 0, 0, 0], [243, -47, 0, -67, -56, 22, 0, -26, 0, 0, 0, 0], [-55, -33, 0, -180, -39, 3, 0, 0, 0, 0, 0, 0], [463, -15, 0, -190, 28, -32, 0, 16, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, -180, 0, -42, 12, 42, 12], [25, 22, 0, 70, 83, -37, 0, -28, 0, 0, 0, 0], [-647, -2, 0, 49, 20, -43, 0, 2, 0, 0, 0, 0], [0, 0, -39, 0, 0, 0, 12, 0, 49, 10, 4, 27], [304, 26, 0, 42, 48, -30, 0, -48, 0, 0, 0, 0], [0, 0, 33, 0, 0, 0, 122, 0, 72, -6, 18, -18], [0, 0, -46, 0, 0, 0, -191, 0, -102, 28, 10, 26], [648, -3, 0, -134, 39, -19, 0, -42, 0, 0, 0, 0], [0, 0, 28, 0, 0, 0, -358, 0, 102, 26, 44, 10], [274, 12, 0, -178, 6, -24, 0, 2, 0, 0, 0, 0], [111, -23, 0, -22, -62, 58, 0, 4, 0, 0, 0, 0], [0, 0, -15, 0, 0, 0, 447, 0, 24, 1, -1, 29], [0, 0, 17, 0, 0, 0, 271, 0, -87, 22, 56, -7], [331, -9, 0, -41, 12, -13, 0, 39, 0, 0, 0, 0], [215, -28, 0, 125, 52, 1, 0, -26, 0, 0, 0, 0], [0, 0, -47, 0, 0, 0, -222, 0, -122, 6, -16, -38], [0, 0, -51, 0, 0, 0, 159, 0, 45, 6, 56, -15], [0, 0, 8, 0, 0, 0, -169, 0, -1, -29, -51, 13], [0, 0, -42, 0, 0, 0, -87, 0, 87, -33, 28, 9], [0, 0, -90, 0, 0, 0, -352, 0, 14, 24, 4, -10], [-623, 5, 0, 21, 36, -24, 0, -78, 0, 0, 0, 0], [-218, -15, 0, -134, -66, 29, 0, 54, 0, 0, 0, 0], [272, 44, 0, 134, 16, -8, 0, 4, 0, 0, 0, 0], [0, 0, -67, 0, 0, 0, 1, 0, 111, 4, -58, 5], [628, -44, 0, 250, -40, 32, 0, 20, 0, 0, 0, 0], [0, 0, -10, 0, 0, 0, -283, 0, 17, -35, -21, 25], [0, 0, 58, 0, 0, 0, 319, 0, -77, -23, 3, -3], [278, 50, 0, -208, -2, -32, 0, -32, 0, 0, 0, 0], [0, 0, 13, 0, 0, 0, 225, 0, -37, 12, -70, 35], [0, 0, 16, 0, 0, 0, -221, 0, 135, -23, 29, -16], [343, -18, 0, -1, 66, 18, 0, -25, 0, 0, 0, 0], [137, -21, 0, 26, -87, 79, 0, 18, 0, 0, 0, 0], [687, -1, 0, 148, -58, 2, 0, 32, 0, 0, 0, 0], [0, 0, 114, 0, 0, 0, -133, 0, 49, 23, -3, -25], [-201, 0, 0, -56, -48, 66, 0, 16, 0, 0, 0, 0], [0, 0, 4, 0, 0, 0, -186, 0, -22, -12, -55, -34], [-316, -24, 0, 56, 6, 4, 0, 12, 0, 0, 0, 0], [0, 0, -66, 0, 0, 0, 243, 0, 133, -31, 57, 14], [-801, -31, 0, -83, -58, 2, 0, -10, 0, 0, 0, 0], [0, 0, 24, 0, 0, 0, -125, 0, -69, -37, -29, -32], [811, -5, 0, -227, 56, -10, 0, -52, 0, 0, 0, 0], [0, 0, 21, 0, 0, 0, -48, 0, 26, -56, -84, 16], [86, 15, 0, 84, 33, 15, 0, 24, 0, 0, 0, 0], [0, 0, 11, 0, 0, 0, 26, 0, 88, -6, 14, -38], [0, 0, -6, 0, 0, 0, 451, 0, -79, -29, -29, -17], [-278, 30, 0, 192, 96, -18, 0, -36, 0, 0, 0, 0], [542, 3, 0, 40, 5, 53, 0, 44, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 511, 0, 110, 22, -24, -8], [-800, -14, 0, 124, 38, -46, 0, -16, 0, 0, 0, 0], [-371, 12, 0, 87, 108, -48, 0, -69, 0, 0, 0, 0], [0, 0, 66, 0, 0, 0, -85, 0, -205, -17, 9, 25], [-613, -39, 0, 242, 45, -23, 0, -6, 0, 0, 0, 0], [0, 0, 104, 0, 0, 0, -377, 0, -69, 13, -24, 5], [38, 9, 0, 236, 0, 25, 0, -36, 0, 0, 0, 0], [0, 0, 24, 0, 0, 0, 231, 0, 18, 42, 46, -54], [0, 0, -24, 0, 0, 0, -45, 0, -169, -33, -5, 2], [500, -31, 0, 56, -68, 13, 0, 52, 0, 0, 0, 0], [0, 0, -33, 0, 0, 0, -31, 0, -35, 44, -10, -37], [523, 21, 0, -52, 58, -74, 0, -32, 0, 0, 0, 0], [111, 51, 0, 98, 3, 55, 0, -6, 0, 0, 0, 0], [234, 51, 0, 190, 18, 23, 0, -30, 0, 0, 0, 0], [-78, -52, 0, 40, -16, 2, 0, 32, 0, 0, 0, 0], [0, 0, 11, 0, 0, 0, -48, 0, 127, -6, 44, 37], [-507, 3, 0, 33, -12, 12, 0, -24, 0, 0, 0, 0], [0, 0, -118, 0, 0, 0, 152, 0, 116, 28, -36, -8], [594, -3, 0, 352, -48, -43, 0, -36, 0, 0, 0, 0], [-393, 12, 0, 100, -90, 68, 0, 60, 0, 0, 0, 0], [0, 0, 20, 0, 0, 0, -262, 0, 32, 8, 45, 0], [-344, -16, 0, 6, 42, -48, 0, -24, 0, 0, 0, 0], [0, 0, -18, 0, 0, 0, -492, 0, 40, -12, -4, -8], [0, 0, 2, 0, 0, 0, 193, 0, -72, -38, 0, 20], [-972, 31, 0, -124, 22, -29, 0, 28, 0, 0, 0, 0], [0, 0, 112, 0, 0, 0, 86, 0, -10, -18, -38, -46], [-709, -6, 0, 285, -30, 0, 0, 75, 0, 0, 0, 0], [-145, -20, 0, 387, -36, -21, 0, 24, 0, 0, 0, 0], [0, 0, -100, 0, 0, 0, 304, 0, -148, 8, 32, -36], [0, 0, 17, 0, 0, 0, -256, 0, -199, 50, 36, 63], [0, 0, 84, 0, 0, 0, -259, 0, 109, 5, 11, 59], [-185, 30, 0, 366, 54, -62, 0, 34, 0, 0, 0, 0], [0, 0, -109, 0, 0, 0, -620, 0, 68, 24, 4, -10], [-120, 55, 0, -172, 82, 31, 0, -68, 0, 0, 0, 0], [0, 0, -12, 0, 0, 0, 469, 0, 26, -38, -98, -20], [181, -51, 0, 284, -68, 106, 0, -32, 0, 0, 0, 0], [674, -60, 0, 188, -72, 88, 0, -12, 0, 0, 0, 0], [0, 0, -40, 0, 0, 0, 475, 0, -167, 29, 9, -4], [-717, 2, 0, -311, -22, 47, 0, 26, 0, 0, 0, 0], [0, 0, 81, 0, 0, 0, -428, 0, -4, 40, 84, 34], [0, 0, 39, 0, 0, 0, -439, 0, 109, -4, -34, 23], [229, -39, 0, 290, -99, -9, 0, -34, 0, 0, 0, 0], [535, 20, 0, -216, 81, -51, 0, -84, 0, 0, 0, 0], [0, 0, -122, 0, 0, 0, -53, 0, 211, 91, -84, -15], [0, 0, 74, 0, 0, 0, -214, 0, -240, -62, -46, -22], [0, 0, 100, 0, 0, 0, 493, 0, -119, 61, -29, 39], [-349, -69, 0, 131, -72, 19, 0, 87, 0, 0, 0, 0], [0, 0, 20, 0, 0, 0, -575, 0, -93, -59, -31, -28], [0, 0, 128, 0, 0, 0, -340, 0, -12, -12, 36, 84], [76, 65, 0, -42, 30, 21, 0, 72, 0, 0, 0, 0], [0, 0, 159, 0, 0, 0, 144, 0, 120, -44, 38, -28], [0, 0, 44, 0, 0, 0, 285, 0, -56, -24, 40, 22], [-309, -51, 0, 286, -63, 77, 0, -42, 0, 0, 0, 0], [287, -21, 0, -164, -118, 74, 0, 8, 0, 0, 0, 0], [0, 0, -126, 0, 0, 0, -340, 0, -152, -22, -42, -64], [0, 0, -114, 0, 0, 0, -553, 0, 103, -37, -32, -19], [0, 0, -57, 0, 0, 0, 202, 0, -343, -8, -54, -17], [0, 0, -142, 0, 0, 0, -1, 0, 31, 39, 11, -20], [0, 0, -4, 0, 0, 0, 10, 0, -302, -2, -26, -48], [631, 45, 0, 386, 69, 39, 0, -10, 0, 0, 0, 0], [282, -22, 0, -524, 38, -28, 0, -16, 0, 0, 0, 0], [0, 0, -62, 0, 0, 0, 458, 0, -150, -4, -78, -38], [0, 0, 70, 0, 0, 0, 931, 0, 83, -89, 21, 1], [0, 0, 120, 0, 0, 0, 388, 0, -10, -2, -17, -62], [0, 0, -110, 0, 0, 0, 612, 0, 130, 20, -96, -46], [0, 0, -74, 0, 0, 0, 433, 0, 118, -44, -22, -36], [560, 60, 0, 406, 90, -84, 0, -38, 0, 0, 0, 0], [378, 23, 0, 760, 38, -43, 0, -4, 0, 0, 0, 0], [0, 0, 139, 0, 0, 0, 439, 0, -95, 16, 14, -27], [-97, -24, 0, 22, 138, 36, 0, -110, 0, 0, 0, 0], [-57, -23, 0, 26, 46, 100, 0, -80, 0, 0, 0, 0], [0, 0, 86, 0, 0, 0, -661, 0, 29, -13, -15, 3], [-749, 24, 0, 214, -72, 34, 0, -58, 0, 0, 0, 0], [0, 0, 31, 0, 0, 0, -1, 0, 171, -73, 103, 13], [-333, 78, 0, -246, -15, -39, 0, 12, 0, 0, 0, 0], [-827, 21, 0, 191, 78, 15, 0, -31, 0, 0, 0, 0], [0, 0, -143, 0, 0, 0, 235, 0, 39, -5, -103, -97], [0, 0, 116, 0, 0, 0, -521, 0, -234, -14, -28, -34], [-19, -45, 0, 66, 33, -55, 0, 62, 0, 0, 0, 0], [856, -33, 0, -152, 6, -1, 0, 24, 0, 0, 0, 0], [-59, -48, 0, -238, -17, -41, 0, -8, 0, 0, 0, 0], [0, 0, -160, 0, 0, 0, -114, 0, -290, 6, -70, 58], [-192, 55, 0, -52, 64, 43, 0, -80, 0, 0, 0, 0], [588, -86, 0, -502, -44, 10, 0, 16, 0, 0, 0, 0], [0, 0, -18, 0, 0, 0, 222, 0, 114, -42, 114, 0], [1058, 70, 0, 420, 156, -36, 0, -24, 0, 0, 0, 0], [265, -18, 0, 34, 30, 92, 0, -6, 0, 0, 0, 0], [0, 0, -84, 0, 0, 0, 1030, 0, -34, 14, -82, 24], [-931, -48, 0, -11, -144, 138, 0, 127, 0, 0, 0, 0], [0, 0, -11, 0, 0, 0, 725, 0, 32, -75, -65, 29], [721, -36, 0, -147, -132, 6, 0, 15, 0, 0, 0, 0], [0, 0, 87, 0, 0, 0, -418, 0, -312, 26, 22, -8], [0, 0, 107, 0, 0, 0, -321, 0, 121, 36, -4, 19], [-117, 60, 0, -38, 174, -18, 0, -62, 0, 0, 0, 0], [761, -39, 0, 48, -81, 21, 0, 60, 0, 0, 0, 0], [0, 0, -148, 0, 0, 0, 547, 0, -117, -53, -72, -43], [0, 0, -33, 0, 0, 0, -46, 0, -191, -16, 10, -25], [0, 0, 20, 0, 0, 0, 187, 0, -183, -35, 113, -28], [0, 0, 128, 0, 0, 0, 823, 0, -480, 52, 36, 2], [25, 42, 0, -202, 36, -36, 0, 86, 0, 0, 0, 0], [0, 0, -46, 0, 0, 0, -837, 0, 281, -13, -79, -45], [0, 0, 138, 0, 0, 0, -394, 0, 400, -4, -47, -40], [332, -12, 0, -134, 30, -108, 0, -14, 0, 0, 0, 0], [-392, -26, 0, 334, -130, 50, 0, 80, 0, 0, 0, 0], [0, 0, 205, 0, 0, 0, 205, 0, -266, 53, -9, 5], [240, -63, 0, 540, -120, 177, 0, 60, 0, 0, 0, 0], [384, 1, 0, -244, 130, -107, 0, -80, 0, 0, 0, 0], [0, 0, 103, 0, 0, 0, -543, 0, 155, 18, 130, -31], [-48, 64, 0, -22, -110, -8, 0, 76, 0, 0, 0, 0], [0, 0, 20, 0, 0, 0, 299, 0, -199, -43, 13, 39], [903, -93, 0, -53, -90, 27, 0, 55, 0, 0, 0, 0], [254, 97, 0, 102, 60, 51, 0, -48, 0, 0, 0, 0], [0, 0, -32, 0, 0, 0, -361, 0, 5, 53, 89, 12], [-776, 104, 0, -150, 18, 12, 0, 48, 0, 0, 0, 0], [0, 0, 6, 0, 0, 0, 290, 0, 484, -58, 6, -52], [0, 0, 29, 0, 0, 0, -332, 0, -30, 12, 126, -78], [-375, 6, 0, 65, 0, 40, 0, -93, 0, 0, 0, 0], [617, -125, 0, -240, -48, -48, 0, -24, 0, 0, 0, 0], [0, 0, -142, 0, 0, 0, -960, 0, 222, -16, -20, -26]]
